
/**
 * 等额本金 摘要
 * @param {*} money 
 * @param {*} year 
 * @param {*} rate 
 */
export function calcBJSummary (moneyW, year, rateB) {
  let money = moneyW * 10000;
  const month = year * 12;
  const rate= rateB / 100;
  let benjin= money / month; //每个月还款本金 
  
  let lxTotal=0;
  let mostlx = 0; // 最高利息
  let emTotal = 0; // 最高月付
  for(let i = 0; i < month; i += 1) {
    const lixi = (money * rate / 12); //每月还款利息 
    money -= benjin; //剩余本金
    lxTotal += lixi; //利息总额

    if(i === 0) {
      mostlx = lixi;
      emTotal = benjin + mostlx;
    }
  }

  return {
    totalRate: parseFloat(lxTotal/10000).toFixed(2),
    totalMoney: parseFloat((moneyW*10000+lxTotal)/10000).toFixed(2),
    rateOfFirstMonth: parseFloat(mostlx/10000).toFixed(2),
    moneyOfFirstMonth: parseFloat(emTotal/10000).toFixed(2),
  }
}

/**
 * 等额本金 列表
 * @param {*} moneyW 
 * @param {*} year 
 * @param {*} rateB 
 * @returns 
 */
export function calcBJList (moneyW, year, rateB) {
  let money = moneyW * 10000;
  const month = year * 12;
  const rate = rateB / 100;
  const benjin = money / month; //每个月还款本金 

  const result = [];
  for(let i = 0; i < month; i += 1) {
    const lx = (money * rate / 12); // 每月还款利息
    money -= benjin; //剩余本金

    result.push({
      benjin: parseFloat(benjin).toFixed(2),
      benxi: parseFloat(benjin +lx).toFixed(2),
      rate: parseFloat(lx).toFixed(2),
      left: parseFloat(money).toFixed(2),
    })
  }

  if (result.length > 0) {
    // 修改最后一条记录的剩余金额为0
    result[result.length - 1].left = 0
  }

  return result;
}

/**
 * 等额本息 摘要
 * @param {*} moneyW 
 * @param {*} year 
 * @param {*} rateB 
 */
export function calcBXSummary (moneyW, year, rateB) {
  let money = moneyW*10000;
  const month = year * 12;
  const rate = rateB/100;
  const emTotal = (money * rate / 12 * Math.pow(1 + rate / 12, month) / (Math.pow(1 + rate/ 12, month) - 1)); //每月还款金额

  let lxTotal = 0; //总利息
  let mostlx = 0;
  for (var i = 0; i < month; i+=1) {
      const lx=(money * rate / 12);  //每月还款利息 
      if(i===0) mostlx=lx; //最高利息
      const em = emTotal-lx; //每月还款本金 
      money -= em;
      lxTotal+=lx;
  }

  return {
    totalRate: parseFloat(lxTotal/10000).toFixed(2),
    totalMoney: parseFloat((moneyW*10000+lxTotal)/10000).toFixed(2),
    rateOfFirstMonth: parseFloat(mostlx/10000).toFixed(2),
    moneyOfFirstMonth: parseFloat(emTotal/10000).toFixed(2),
  }
}

/**
 * 等额本息 列表
 * @param {*} moneyW 
 * @param {*} year 
 * @param {*} rateB 
 * @returns 
 */
export function calcBXList (moneyW, year, rateB) {
  let money = moneyW*10000;
  const month = year * 12;
  const rate = rateB/100;
  const emTotal = (money * rate / 12 * Math.pow(1 + rate / 12, month) / (Math.pow(1 + rate/ 12, month) - 1)); //每月还款金额

  const result = [];
  for(let i = 0; i < month; i += 1) {
    const lx=(money * rate / 12);  //每月还款利息 
    const em = emTotal-lx; //每月还款本金 
    money = money - em;


    result.push({
      benjin: parseFloat(em).toFixed(2),
      benxi: parseFloat(em +lx).toFixed(2),
      rate: parseFloat(lx).toFixed(2),
      left: parseFloat(money).toFixed(2),
    })
  }

  if (result.length > 0) {
    // 修改最后一条记录的剩余金额为0
    result[result.length - 1].left = 0
  }

  return result;
}
